# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["OutboundEmailComplainedWebhookEvent", "Data"]


class Data(BaseModel):
    complained_at: str = FieldInfo(alias="complainedAt")

    message_id: str = FieldInfo(alias="messageId")

    recipients: List[str]

    complaint_feedback_type: Optional[str] = FieldInfo(alias="complaintFeedbackType", default=None)

    email_id: Optional[str] = FieldInfo(alias="emailId", default=None)

    feedback_id: Optional[str] = FieldInfo(alias="feedbackId", default=None)

    user_agent: Optional[str] = FieldInfo(alias="userAgent", default=None)


class OutboundEmailComplainedWebhookEvent(BaseModel):
    attempt: int

    data: Data

    event: Literal["outbound.email.complained"]

    timestamp: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Any, cast

import httpx

from .._types import Body, Query, Headers, NotGiven, not_given
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.meta_webhooks_schema_response import MetaWebhooksSchemaResponse

__all__ = ["MetaResource", "AsyncMetaResource"]


class MetaResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> MetaResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/aiinbx/aiinbx-py#accessing-raw-response-data-eg-headers
        """
        return MetaResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MetaResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/aiinbx/aiinbx-py#with_streaming_response
        """
        return MetaResourceWithStreamingResponse(self)

    def webhooks_schema(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MetaWebhooksSchemaResponse:
        """Internal endpoint to expose webhook event schemas to SDK generators."""
        return cast(
            MetaWebhooksSchemaResponse,
            self._get(
                "/_meta/webhooks",
                options=make_request_options(
                    extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
                ),
                cast_to=cast(
                    Any, MetaWebhooksSchemaResponse
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )


class AsyncMetaResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncMetaResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/aiinbx/aiinbx-py#accessing-raw-response-data-eg-headers
        """
        return AsyncMetaResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMetaResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/aiinbx/aiinbx-py#with_streaming_response
        """
        return AsyncMetaResourceWithStreamingResponse(self)

    async def webhooks_schema(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MetaWebhooksSchemaResponse:
        """Internal endpoint to expose webhook event schemas to SDK generators."""
        return cast(
            MetaWebhooksSchemaResponse,
            await self._get(
                "/_meta/webhooks",
                options=make_request_options(
                    extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
                ),
                cast_to=cast(
                    Any, MetaWebhooksSchemaResponse
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )


class MetaResourceWithRawResponse:
    def __init__(self, meta: MetaResource) -> None:
        self._meta = meta

        self.webhooks_schema = to_raw_response_wrapper(
            meta.webhooks_schema,
        )


class AsyncMetaResourceWithRawResponse:
    def __init__(self, meta: AsyncMetaResource) -> None:
        self._meta = meta

        self.webhooks_schema = async_to_raw_response_wrapper(
            meta.webhooks_schema,
        )


class MetaResourceWithStreamingResponse:
    def __init__(self, meta: MetaResource) -> None:
        self._meta = meta

        self.webhooks_schema = to_streamed_response_wrapper(
            meta.webhooks_schema,
        )


class AsyncMetaResourceWithStreamingResponse:
    def __init__(self, meta: AsyncMetaResource) -> None:
        self._meta = meta

        self.webhooks_schema = async_to_streamed_response_wrapper(
            meta.webhooks_schema,
        )
